==> v1.0.2.1016.tar.gz: athena-opt-demo/demo-athenaopt_backend/develop/src/main/java/com/digiwin/athena/app/ptc/service/production/ProductionCreateEAIService.java <==
package com.digiwin.athena.app.ptc.service.production;

import com.alibaba.fastjson.TypeReference;
import com.alibaba.nacos.common.utils.CollectionUtils;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.infra.common.enums.TabStatusEnums;
import com.digiwin.athena.app.ptc.infra.entity.ProductionDetailsEntity;
import com.digiwin.athena.app.ptc.infra.entity.ReceivablesDetailEntity;
import com.digiwin.athena.app.ptc.infra.service.ProductionDetailsService;
import com.digiwin.athena.app.ptc.infra.service.ReceivablesDetailService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.common.util.RedisUtil;
import org.apache.commons.lang.time.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @auther: zhenggl
 * @date: 2023/9/12
 */
@Service
public class ProductionCreateEAIService extends AbsEAIService {

    @Resource
    private ProductionDetailsService productionDetailsService;

    @Resource
    private ReceivablesDetailService receivablesDetailService;

    @Autowired
    private RedisUtil redisUtil;


    @Override
    public String getServiceName() {
        return ProductionUtil.PRODUCTION_TASK_CREATE;
    }

    //随机赋值list
    List<ProductionDetailsEntity> list = Arrays.asList(
            new ProductionDetailsEntity("001", "一号工厂", "一号工厂刘晓鹏"),
            new ProductionDetailsEntity("002", "二号工厂", "二号工厂饶文豪"),
            new ProductionDetailsEntity("003", "三号工厂", "三号工厂卢人辅"));


    @Override
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {

        EAIRequest eaiRequest = EAIRequest.build(messageBody);
        List<ProductionDetailsEntity> productionDetailsEntities = eaiRequest.getObject("get_data", new TypeReference<List<ProductionDetailsEntity>>() {
        });


        //根据工单单号查询应收表
        List<String> woNoList = productionDetailsEntities.stream().map(ProductionDetailsEntity::getWorkNo).collect(Collectors.toList());
        LambdaQueryWrapper<ReceivablesDetailEntity> receivablesLmq = new LambdaQueryWrapper();
        receivablesLmq.in(ReceivablesDetailEntity::getWorkNo, woNoList);
        List<ReceivablesDetailEntity> receivablesDetailEntities = receivablesDetailService.list(receivablesLmq);




        //默认赋值
        for (ProductionDetailsEntity productionDetailsEntity : productionDetailsEntities) {
            Random random = new Random();
            int randomNumber = random.nextInt(3);
            productionDetailsEntity.setFactoryNo(this.list.get(randomNumber).getFactoryNo());
            productionDetailsEntity.setFactoryName(this.list.get(randomNumber).getFactoryName());
            productionDetailsEntity.setProductionManagementPerson(this.list.get(randomNumber).getProductionManagementPerson());
            productionDetailsEntity.setProductionManagementDepartment("生管一部");
            productionDetailsEntity.setProduceBoss("23467345221");
            productionDetailsEntity.setProductionStatus(TabStatusEnums.PENDING.getValue().toString());
            productionDetailsEntity.setNature(String.valueOf(randomNumber));
            String batchNo = cteateBatchNo();
            productionDetailsEntity.setBatchNo("MMDD-"+batchNo);
            //预计产量赋值
            if (CollectionUtils.isNotEmpty(list)) {
                for (ReceivablesDetailEntity receivablesDetailEntity : receivablesDetailEntities) {
                    productionDetailsEntity.setExpectedQuantity(receivablesDetailEntity.getQuantity());
                    //取应收日期前后5天
                    productionDetailsEntity.setExpectedCommencementDate(DateUtils.addDays(receivablesDetailEntity.getReceivableDate(), random.nextInt(11) - 5));
                    //取预计开工日期后5-10天
                    productionDetailsEntity.setEstimatedCompletionDate(DateUtils.addDays(productionDetailsEntity.getExpectedCommencementDate(), random.nextInt(6) + 5));
                    productionDetailsEntity.setSkuCode(receivablesDetailEntity.getSkuCode());
                    productionDetailsEntity.setSkuName(receivablesDetailEntity.getSkuName());
                    productionDetailsEntity.setSkuSpec(receivablesDetailEntity.getSkuSpec());
                    productionDetailsEntity.setUnit("待定");
                }
            }
        }

        return buildOK();
    }

    private String cteateBatchNo(){
        StringBuilder sb = new StringBuilder();
        Long batchNo;
        if (redisUtil.getRedisTemplate().hasKey(ProductionUtil.KEY)) {
            batchNo = redisUtil.incrBy(ProductionUtil.KEY, 1);
        } else {
            redisUtil.setObject(ProductionUtil.KEY, 1);
            batchNo = 1L;
        }

        int prefix = 5-batchNo.toString().length();
        for (int i = 0; i < prefix; i++) {
            sb.append("0");
        }
        return sb.append(batchNo).toString();
    }
}

==> v1.0.2.1030.tar.gz: athena-opt-demo/demo-athenaopt_backend/develop/src/main/java/com/digiwin/athena/app/ptc/service/production/ProductionCreateEAIService.java <==
package com.digiwin.athena.app.ptc.service.production;

import com.alibaba.fastjson.TypeReference;
import com.alibaba.nacos.common.utils.CollectionUtils;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.infra.common.enums.TabStatusEnums;
import com.digiwin.athena.app.ptc.infra.entity.ProductionDetailsEntity;
import com.digiwin.athena.app.ptc.infra.entity.ReceivablesDetailEntity;
import com.digiwin.athena.app.ptc.infra.service.ProductionDetailsService;
import com.digiwin.athena.app.ptc.infra.service.ReceivablesDetailService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.common.util.RedisUtil;
import org.apache.commons.lang.time.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @auther: zhenggl
 * @date: 2023/9/12
 */
@Service
public class ProductionCreateEAIService extends AbsEAIService {

    @Resource
    private ProductionDetailsService productionDetailsService;

    @Resource
    private ReceivablesDetailService receivablesDetailService;

    @Autowired
    private RedisUtil redisUtil;


    @Override
    public String getServiceName() {
        return ProductionUtil.PRODUCTION_TASK_CREATE;
    }

    //随机赋值list
    private List<ProductionDetailsEntity> list = Arrays.asList(
            new ProductionDetailsEntity("001", "一号工厂", "一号工厂刘晓鹏"),
            new ProductionDetailsEntity("002", "二号工厂", "二号工厂饶文豪"),
            new ProductionDetailsEntity("003", "三号工厂", "三号工厂卢人辅"));


    @Override
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {

        EAIRequest eaiRequest = EAIRequest.build(messageBody);
        List<ProductionDetailsEntity> productionDetailsEntities = eaiRequest.getObject("get_data", new TypeReference<List<ProductionDetailsEntity>>() {
        });


        //根据工单单号查询应收表
        List<String> woNoList = productionDetailsEntities.stream().map(ProductionDetailsEntity::getWorkNo).collect(Collectors.toList());
        LambdaQueryWrapper<ReceivablesDetailEntity> receivablesLmq = new LambdaQueryWrapper();
        receivablesLmq.in(ReceivablesDetailEntity::getWorkNo, woNoList);
        List<ReceivablesDetailEntity> receivablesDetailEntities = receivablesDetailService.list(receivablesLmq);



        Random random = new Random();
        //默认赋值
        for (ProductionDetailsEntity productionDetailsEntity : productionDetailsEntities) {
            int randomNumber = random.nextInt(2)+1;
            productionDetailsEntity.setFactoryNo(this.list.get(randomNumber).getFactoryNo());
            productionDetailsEntity.setFactoryName(this.list.get(randomNumber).getFactoryName());
            productionDetailsEntity.setProductionManagementPerson(this.list.get(randomNumber).getProductionManagementPerson());
            productionDetailsEntity.setProductionManagementDepartment("生管一部");
            productionDetailsEntity.setProduceBoss("23467345221");
            productionDetailsEntity.setProductionStatus(TabStatusEnums.PENDING.getValue().toString());
            productionDetailsEntity.setNature(String.valueOf(randomNumber));
            String batchNo = createBatchNo();
            productionDetailsEntity.setBatchNo("MMDD-"+batchNo);
            //预计产量赋值
            if (CollectionUtils.isNotEmpty(list)) {
                for (ReceivablesDetailEntity receivablesDetailEntity : receivablesDetailEntities) {
                    productionDetailsEntity.setExpectedQuantity(receivablesDetailEntity.getQuantity());
                    //取应收日期前后5天
                    productionDetailsEntity.setExpectedCommencementDate(DateUtils.addDays(receivablesDetailEntity.getReceivableDate(), random.nextInt(11) - 5));
                    //取预计开工日期后5-10天
                    productionDetailsEntity.setEstimatedCompletionDate(DateUtils.addDays(productionDetailsEntity.getExpectedCommencementDate(), random.nextInt(6) + 5));
                    productionDetailsEntity.setSkuCode(receivablesDetailEntity.getSkuCode());
                    productionDetailsEntity.setSkuName(receivablesDetailEntity.getSkuName());
                    productionDetailsEntity.setSkuSpec(receivablesDetailEntity.getSkuSpec());
                    productionDetailsEntity.setUnit("待定");
                }
            }
        }

        return buildOK();
    }

    private String createBatchNo(){
        StringBuffer sb = new StringBuffer();
        Long batchNo;
        if (redisUtil.getRedisTemplate().hasKey(ProductionUtil.KEY)) {
            batchNo = redisUtil.incrBy(ProductionUtil.KEY, 1);
        } else {
            redisUtil.setObject(ProductionUtil.KEY, 1);
            batchNo = 1L;
        }

        int prefix = 5-batchNo.toString().length();
        for (int i = 0; i < prefix; i++) {
            sb.append("0");
        }
        return sb.append(batchNo).toString();
    }
}
